@@ -33,27 +33,19 @@ class Builder:
 
             for each_file in self.drive.media(public=True):
                 if doc_id == each_file.id:
-                    for folder in self.drive.folders():
-                        if folder.id == doc.parents:
-                            break
-                    else:
-                        print("folder not found!")
-                        return link
-
-                    path = f'{self.path_join(folder, "")}{doc.pointer.lower().replace(" ", "_")}'
-                    return path
+                    folder = self.find_folder(each_file.parents)
+                    return f'{self.path_join(folder, "")}{doc.pointer.lower().replace(" ", "_")}'
             else:
                 for doc in self.drive.docs(public=True):
                     if doc_id == doc.id:
-                        for folder in self.drive.folders():
-                            if folder.id == doc.parents:
-                                break
-                        else:
-                            print("folder not found!")
-                            return link
+                        folder = self.find_folder(doc.parents)
+                        # for folder in self.drive.folders():
+                        #     if folder.id == doc.parents:
+                        #         break
+                        # else: # folder not found
+                        #     return link
 
-                        path = f'{self.path_join(folder, "")}{doc.pointer.lower().replace(" ", "_")}.html'
-                        return path
+                        return f'{self.path_join(folder, "")}{doc.pointer.lower().replace(" ", "_")}.html'
 
         return link
 
